@@ -346,6 +346,27 @@ func expectNoPodNow(ctx context.Context, parentResource client.Object, podName s
 	).To(MatchError("pods \""+podName+"\" not found"), "Pod exists when it should not")
 }
 
+func expectPodNow(ctx context.Context, parentResource client.Object, podName string, additionalOffset ...int) *corev1.Pod {
+	pod := &corev1.Pod{}
+	ExpectWithOffset(
+		resolveOffset(additionalOffset),
+		k8sClient.Get(ctx, resourceKey(parentResource, podName), pod),
+	).To(Succeed(), "Pod should exist", "name", podName, "namespace", parentResource.GetNamespace())
+	return pod
+}
+
+func expectPodWithChecks(ctx context.Context, parentResource client.Object, podName string, additionalChecks func(Gomega, *corev1.Pod), additionalOffset ...int) *corev1.Pod {
+	pod := &corev1.Pod{}
+	EventuallyWithOffset(resolveOffset(additionalOffset), func(g Gomega) {
+		g.Expect(k8sClient.Get(ctx, resourceKey(parentResource, podName), pod)).To(Succeed(), "Expected Pod does not exist")
+
+		if additionalChecks != nil {
+			additionalChecks(g, pod)
+		}
+	}).Should(Succeed())
+	return pod
+}
+
 func expectService(ctx context.Context, parentResource client.Object, serviceName string, selectorLables map[string]string, isHeadless bool, additionalOffset ...int) *corev1.Service {
 	return expectServiceWithChecks(ctx, parentResource, serviceName, selectorLables, isHeadless, nil, resolveOffset(additionalOffset))
 }
@@ -353,7 +374,7 @@ func expectService(ctx context.Context, parentResource client.Object, serviceNam
 func expectServiceWithChecks(ctx context.Context, parentResource client.Object, serviceName string, selectorLables map[string]string, isHeadless bool, additionalChecks func(Gomega, *corev1.Service), additionalOffset ...int) *corev1.Service {
 	service := &corev1.Service{}
 	EventuallyWithOffset(resolveOffset(additionalOffset), func(g Gomega) {
-		Expect(k8sClient.Get(ctx, resourceKey(parentResource, serviceName), service)).To(Succeed(), "Expected Service does not exist")
+		g.Expect(k8sClient.Get(ctx, resourceKey(parentResource, serviceName), service)).To(Succeed(), "Expected Service does not exist")
 
 		g.Expect(service.Spec.Selector).To(Equal(selectorLables), "Service is not pointing to the correct Pods.")
 
@@ -367,27 +388,13 @@ func expectServiceWithChecks(ctx context.Context, parentResource client.Object,
 			additionalChecks(g, service)
 		}
 	}).Should(Succeed())
-
-	By("recreating the Service after it is deleted")
-	ExpectWithOffset(resolveOffset(additionalOffset), k8sClient.Delete(ctx, service)).To(Succeed())
-	EventuallyWithOffset(
-		resolveOffset(additionalOffset),
-		func() (types.UID, error) {
-			newResource := &corev1.Service{}
-			err := k8sClient.Get(ctx, resourceKey(parentResource, serviceName), newResource)
-			if err != nil {
-				return "", err
-			}
-			return newResource.UID, nil
-		}).Should(And(Not(BeEmpty()), Not(Equal(service.UID))), "New Service, with new UID, not created.")
-
 	return service
 }
 
 func expectServiceWithConsistentChecks(ctx context.Context, parentResource client.Object, serviceName string, selectorLables map[string]string, isHeadless bool, additionalChecks func(Gomega, *corev1.Service), additionalOffset ...int) *corev1.Service {
 	service := &corev1.Service{}
 	ConsistentlyWithOffset(resolveOffset(additionalOffset), func(g Gomega) {
-		Expect(k8sClient.Get(ctx, resourceKey(parentResource, serviceName), service)).To(Succeed(), "Expected Service does not exist")
+		g.Expect(k8sClient.Get(ctx, resourceKey(parentResource, serviceName), service)).To(Succeed(), "Expected Service does not exist")
 
 		g.Expect(service.Spec.Selector).To(Equal(selectorLables), "Service is not pointing to the correct Pods.")
 
@@ -411,10 +418,23 @@ func expectNoService(ctx context.Context, parentResource client.Object, serviceN
 	}).Should(MatchError("services \""+serviceName+"\" not found"), message, "Service exists when it should not")
 }
 
+func eventuallyExpectNoService(ctx context.Context, parentResource client.Object, serviceName string, message string, additionalOffset ...int) {
+	EventuallyWithOffset(resolveOffset(additionalOffset), func() error {
+		return k8sClient.Get(ctx, resourceKey(parentResource, serviceName), &corev1.Service{})
+	}).Should(MatchError("services \""+serviceName+"\" not found"), message, "Service exists when it should not")
+}
+
 func expectNoServices(ctx context.Context, parentResource client.Object, message string, serviceNames []string, additionalOffset ...int) {
 	ConsistentlyWithOffset(resolveOffset(additionalOffset), func(g Gomega) {
 		for _, serviceName := range serviceNames {
-			g.Expect(k8sClient.Get(ctx, resourceKey(parentResource, serviceName), &corev1.Service{})).To(MatchError("services \""+serviceName+"\" not found"), message)
+			g.Expect(k8sClient.Get(ctx, resourceKey(parentResource, serviceName), &corev1.Service{})).To(MatchError("services \""+serviceName+"\" not found"), message, "service", serviceName)
+		}
+	}).Should(Succeed())
+}
+func eventuallyExpectNoServices(ctx context.Context, parentResource client.Object, message string, serviceNames []string, additionalOffset ...int) {
+	EventuallyWithOffset(resolveOffset(additionalOffset), func(g Gomega) {
+		for _, serviceName := range serviceNames {
+			g.Expect(k8sClient.Get(ctx, resourceKey(parentResource, serviceName), &corev1.Service{})).To(MatchError("services \""+serviceName+"\" not found"), message, "service", serviceName)
 		}
 	}).Should(Succeed())
 }
@@ -432,20 +452,6 @@ func expectIngressWithChecks(ctx context.Context, parentResource client.Object,
 			additionalChecks(g, ingress)
 		}
 	}).Should(Succeed())
-
-	By("recreating the Ingress after it is deleted")
-	ExpectWithOffset(resolveOffset(additionalOffset), k8sClient.Delete(ctx, ingress)).To(Succeed())
-	EventuallyWithOffset(
-		resolveOffset(additionalOffset),
-		func() (types.UID, error) {
-			newResource := &netv1.Ingress{}
-			err := k8sClient.Get(ctx, resourceKey(parentResource, ingressName), newResource)
-			if err != nil {
-				return "", err
-			}
-			return newResource.UID, nil
-		}).Should(And(Not(BeEmpty()), Not(Equal(ingress.UID))), "New Ingress, with new UID, not created.")
-
 	return ingress
 }
 
@@ -468,6 +474,12 @@ func expectNoIngress(ctx context.Context, parentResource client.Object, ingressN
 	}).Should(MatchError("ingresses.networking.k8s.io \""+ingressName+"\" not found"), "Ingress exists when it should not")
 }
 
+func eventuallyExpectNoIngress(ctx context.Context, parentResource client.Object, ingressName string, additionalOffset ...int) {
+	EventuallyWithOffset(resolveOffset(additionalOffset), func() error {
+		return k8sClient.Get(ctx, resourceKey(parentResource, ingressName), &netv1.Ingress{})
+	}).Should(MatchError("ingresses.networking.k8s.io \""+ingressName+"\" not found"), "Ingress exists when it should not")
+}
+
 func expectPodDisruptionBudget(ctx context.Context, parentResource client.Object, podDisruptionBudgetName string, selector *metav1.LabelSelector, maxUnavailable intstr.IntOrString, additionalOffset ...int) *policyv1.PodDisruptionBudget {
 	return expectPodDisruptionBudgetWithChecks(ctx, parentResource, podDisruptionBudgetName, selector, maxUnavailable, nil, resolveOffset(additionalOffset))
 }
@@ -485,20 +497,6 @@ func expectPodDisruptionBudgetWithChecks(ctx context.Context, parentResource cli
 			additionalChecks(g, podDisruptionBudget)
 		}
 	}).Should(Succeed())
-
-	By("recreating the PodDisruptionBudget after it is deleted")
-	ExpectWithOffset(resolveOffset(additionalOffset), k8sClient.Delete(ctx, podDisruptionBudget)).To(Succeed())
-	EventuallyWithOffset(
-		resolveOffset(additionalOffset),
-		func() (types.UID, error) {
-			newResource := &policyv1.PodDisruptionBudget{}
-			err := k8sClient.Get(ctx, resourceKey(parentResource, podDisruptionBudgetName), newResource)
-			if err != nil {
-				return "", err
-			}
-			return newResource.UID, nil
-		}).Should(And(Not(BeEmpty()), Not(Equal(podDisruptionBudget.UID))), "New PodDisruptionBudget, with new UID, not created.")
-
 	return podDisruptionBudget
 }
 
@@ -518,20 +516,6 @@ func expectConfigMapWithChecks(ctx context.Context, parentResource client.Object
 			additionalChecks(g, configMap)
 		}
 	}).Should(Succeed())
-
-	By("recreating the ConfigMap after it is deleted")
-	ExpectWithOffset(resolveOffset(additionalOffset), k8sClient.Delete(ctx, configMap)).To(Succeed())
-	EventuallyWithOffset(
-		resolveOffset(additionalOffset),
-		func() (types.UID, error) {
-			newResource := &corev1.ConfigMap{}
-			err := k8sClient.Get(ctx, resourceKey(parentResource, configMapName), newResource)
-			if err != nil {
-				return "", err
-			}
-			return newResource.UID, nil
-		}).Should(And(Not(BeEmpty()), Not(Equal(configMap.UID))), "New ConfigMap, with new UID, not created.")
-
 	return configMap
 }
 
@@ -574,20 +558,6 @@ func expectDeploymentWithChecks(ctx context.Context, parentResource client.Objec
 			additionalChecks(g, deployment)
 		}
 	}).Should(Succeed())
-
-	By("recreating the Deployment after it is deleted")
-	ExpectWithOffset(resolveOffset(additionalOffset), k8sClient.Delete(ctx, deployment)).To(Succeed())
-	EventuallyWithOffset(
-		resolveOffset(additionalOffset),
-		func() (types.UID, error) {
-			newResource := &appsv1.Deployment{}
-			err := k8sClient.Get(ctx, resourceKey(parentResource, deploymentName), newResource)
-			if err != nil {
-				return "", err
-			}
-			return newResource.UID, nil
-		}).Should(And(Not(BeEmpty()), Not(Equal(deployment.UID))), "New Deployment, with new UID, not created.")
-
 	return deployment
 }
 
